@@ -7,9 +7,15 @@ from optparse import OptionParser
 from pathlib import Path, PurePath
 from sys import stderr
 from time import sleep as time_sleep
+from typing import Optional
 
 import json5 as json
-import vlc
+
+try:
+    import vlc
+except OSError:
+    print("vlc not found.", file=sys.stderr)
+    sys.exit(1)
 
 from exclock import __VERSION__
 from exclock.entities import ClockTimer
@@ -70,7 +76,7 @@ def check_raw_clock(d) -> None:
 
 
 def get_option_parser():
-    usage = "exclock [(filename) | --list]"
+    usage = "exclock [(filename) | --list | --time {time}]"
     parser = OptionParser(usage=usage, version=__VERSION__)
     parser.add_option(
         "-l",
@@ -80,7 +86,12 @@ def get_option_parser():
         dest="show_list",
         help="show clock names in your PC and exit",
     )
-    parser.add_option("-t", "--time", dest="specified_time", action="store")
+    parser.add_option(
+        "-t",
+        "--time",
+        dest="specified_time",
+        action="store",
+        help="Time which spends until or to specified")
 
     return parser
 
@@ -90,16 +101,21 @@ def show_list_main(stdout=sys.stdout) -> None:
         print(basename, file=stdout)
 
 
-def specified_time_main(opt, args) -> None:
-    time_sec = None
-    if is_specific_time_str(opt.specified_time):
+def get_time(time_: str) -> Optional[int]:
+    if is_specific_time_str(time_):
         now_ = datetime.now()
-        time_ = get_specific_time_from_str(opt.specified_time)
-        time_sec = convert_specific_time_to_time_delta(
-            time_, (now_.hour, now_.minute, now_.second))
-    elif is_time_delta_str(opt.specified_time):
-        time_sec = get_time_delta_from_str(opt.specified_time)
-    else:
+        time_info = get_specific_time_from_str(time_)
+        return convert_specific_time_to_time_delta(
+            time_info, (now_.hour, now_.minute, now_.second))
+    elif is_time_delta_str(time_):
+        return get_time_delta_from_str(time_)
+
+    return None
+
+
+def specified_time_main(opt, args) -> None:
+    time_sec = get_time(opt.specified_time)
+    if time_sec is None:
         print("time format is illegal.", file=sys.stderr)
         sys.exit(1)
 
