@@ -4,9 +4,10 @@
 from io import StringIO
 from unittest import mock
 
+import freezegun
 import pytest
 
-from exclock.main import check_raw_clock, get_title_from_json_filename, show_list_main
+from exclock.main import check_raw_clock, get_time, get_title_from_json_filename, show_list_main
 
 from .test_const import TEST_CLOCK_DIR_IN_SYS
 
@@ -132,3 +133,20 @@ def test_show_list_main():
     outputs = set(stdout.getvalue().split('\n'))
     assert 'pomodoro' in outputs
     assert 'clock_in_sys.json' in outputs
+
+
+GET_TIME_PARAMS = [
+    ("12", 12),
+    ("12s", 12),
+    ("1m2s", 1 * 60 + 2),
+    ("2m", 60 * 2),
+    ("abc", None),
+    ("00:01", 60),
+    ("23:59", 23 * 60 * 60 + 59 * 60),
+]
+
+
+@freezegun.freeze_time('2020-01-01')
+@pytest.mark.parametrize("s, expect", GET_TIME_PARAMS)
+def test_get_time(s, expect):
+    assert get_time(s) == expect
